package edu.prlab.tyler.iotgateway.cloud.config;

import edu.prlab.tyler.iotgateway.cloud.pojo.Document;
import edu.prlab.tyler.iotgateway.cloud.pojo.device.Device;
import edu.prlab.tyler.iotgateway.cloud.pojo.device.Manufacturer;
import edu.prlab.tyler.iotgateway.cloud.pojo.device.Model;
import edu.prlab.tyler.iotgateway.cloud.pojo.privacy.PrivacyPolicy;
import edu.prlab.tyler.iotgateway.cloud.pojo.privacy.PrivacyPolicyReport;
import edu.prlab.tyler.iotgateway.cloud.pojo.privacy.p3p.*;
import edu.prlab.tyler.iotgateway.cloud.services.DeviceService;
import edu.prlab.tyler.iotgateway.cloud.services.DocumentService;
import edu.prlab.tyler.iotgateway.cloud.services.PrivacyPolicyReportService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.core.io.Resource;
import org.springframework.mock.web.MockMultipartFile;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.io.InputStream;
import java.util.Optional;

import static java.util.Arrays.asList;

@Component
public class DefaultData implements ApplicationRunner {

    private DeviceService deviceService;
    private PrivacyPolicyReportService privacyPolicyReportService;
    private DocumentService documentService;

    @Autowired
    public DefaultData(DeviceService deviceService,
                       PrivacyPolicyReportService privacyPolicyReportService,
                       DocumentService documentService) {
        this.deviceService = deviceService;
        this.privacyPolicyReportService = privacyPolicyReportService;
        this.documentService = documentService;
    }

    @Value("classpath:document/心跳血氧機檢測報告.pdf")
    Resource oxygenResource;

    @Value("classpath:document/紫外線傳感器檢測報告.pdf")
    Resource sensorResource;

    @Value("classpath:document/粉塵濃度感測器檢測報告.pdf")
    Resource dustResource;

    @Value("classpath:document/溫溼度感測器檢測報告.pdf")
    Resource tempResource;

    @Value("classpath:document/氣體感測器檢測報告.pdf")
    Resource gasResource;

    @Override
    public void run(ApplicationArguments args) {
        //心跳血氧機
        Device oxygenDevice = Device.builder()
                .udn("a1252c49-4188-4e6d-a32e-66604c664fb8")
                .name("心跳血氧機")
                .type(Device.Type.Sensor)
                .manufacturer(Manufacturer.builder()
                        .name("Maxim Integrated")
                        .serialNumber("3176927193")
                        .url("https://www.maximintegrated.com/en.html")
                        .build())
                .model(Model.builder()
                        .name("心跳血氧機")
                        .description("本設備檢測人體內產生的小信號，例如心臟產生的電信號，此信號通常經過調理後傳輸至微控制器，進行儲存、計算或顯示在健康監測設備上。本設備測量數據用於健身監測，或者被醫療保健專家用於判定被觀察病人的總體健康狀況")
                        .url("https://www.maximintegrated.com/en/products/sensors/MAX30100.html")
                        .build())
                .upc("B00HXXO332")
                .location("25.013068, 121.541651")
                .status(Device.Status.Disconnected)
                .build();

        deviceService.add(oxygenDevice);

        PrivacyPolicy oxygenPrivacyPolicy1 = PrivacyPolicy.builder()
                .id("abe5ca7b-780e-4857-87e6-014870fe0a3e")
                .description("本APP會蒐集使用者心跳作為第三方之分析資料。")
                .collector(Collector.builder()
                        .name("AirRadio")
                        .email("airradio@gmail.com.tw")
                        .phone("0987654177")
                        .build())
                .access(Access.NON_IDENT)
                .dispute(Dispute.builder()
                        .relatedOrganization("地方法院")
                        .type(Dispute.Type.LAW).build())
                .remedies(asList(Remedy.builder()
                        .type(Remedy.Type.LAW)
                        .build()))
                .statements(asList(Statement.builder()
                        .consequence("a1252c49-4188-4e6d-a32e-66604c664fl4")
                        .purposes(asList(Purpose.builder()
                                .type(Purpose.Type.PSEUDO_ANALYSIS)
                                .description("本APP會蒐集使用者心跳作為第三方之分析資料。")
                                .build()))
                        .data(asList(Datum.builder()
                                .type(Datum.Type.OTHER_CATEGORY)
                                .description("心跳健康資料")
                                .build()))
                        .recipients(asList(Recipient.builder()
                                .entity("AirRadio")
                                .type(Recipient.Type.OURS)
                                .build()))
                        .retention(Retention.STATED_PURPOSE)
                        .build(), Statement.builder()
                        .consequence("a1252c49-4188-4e6d-a32e-66604c664f45")
                        .purposes(asList(Purpose.builder()
                                .type(Purpose.Type.PSEUDO_ANALYSIS)
                                .description("本APP會蒐集使用者心跳作為第三方之分析資料。")
                                .build()))
                        .data(asList(Datum.builder()
                                .type(Datum.Type.OTHER_CATEGORY)
                                .description("心跳健康資料")
                                .build()))
                        .recipients(asList(Recipient.builder()
                                .entity("AirRadio")
                                .type(Recipient.Type.OURS)
                                .build()))
                        .retention(Retention.STATED_PURPOSE)
                        .build()
                ))
                .build();

        PrivacyPolicy oxygenPrivacyPolicy2 = PrivacyPolicy.builder()
                .id("abe5ca7b-780e-4857-87e6-014870fe0a3e")
                .description("本APP會蒐集使用者血氧作為第三方之分析資料。")
                .collector(Collector.builder()
                        .name("AirRadio")
                        .email("airradio@gmail.com.tw")
                        .phone("0987654177")
                        .build())
                .access(Access.NON_IDENT)
                .dispute(Dispute.builder()
                        .relatedOrganization("地方法院")
                        .type(Dispute.Type.LAW).build())
                .remedies(asList(Remedy.builder()
                        .type(Remedy.Type.LAW)
                        .build()))
                .statements(asList(Statement.builder()
                        .consequence("a1252c49-4188-4e6d-a32e-66604c664f48")
                        .purposes(asList(Purpose.builder()
                                .type(Purpose.Type.PSEUDO_ANALYSIS)
                                .description("本APP會蒐集使用者血氧作為第三方之分析資料。")
                                .build()))
                        .data(asList(Datum.builder()
                                .type(Datum.Type.OTHER_CATEGORY)
                                .description("血氧資料")
                                .build()))
                        .recipients(asList(Recipient.builder()
                                .entity("AirRadio")
                                .type(Recipient.Type.OURS)
                                .build()))
                        .retention(Retention.STATED_PURPOSE)
                        .build(), Statement.builder()
                        .consequence("a1252c49-4188-4e6d-a32e-66604c664f89")
                        .purposes(asList(Purpose.builder()
                                .type(Purpose.Type.PSEUDO_ANALYSIS)
                                .description("本APP會蒐集使用者血氧作為第三方之分析資料。")
                                .build()))
                        .data(asList(Datum.builder()
                                .type(Datum.Type.OTHER_CATEGORY)
                                .description("血氧資料")
                                .build()))
                        .recipients(asList(Recipient.builder()
                                .entity("AirRadio")
                                .type(Recipient.Type.OURS)
                                .build()))
                        .retention(Retention.STATED_PURPOSE)
                        .build()
                ))
                .build();

        Document document = resourceToMultipartFile(oxygenResource)
                .flatMap(documentService::add)
                .orElse(Document.builder().build());

        PrivacyPolicyReport oxygenPrivacyPolicyReport = PrivacyPolicyReport.builder()
                .id("0cfb6be3-6f0f-4e63-85b8-e9c936707c0a")
                .version("1.0")
                .description("本APP會蒐集使用者心跳、血氧作為第三方之分析資料。")
                .device(oxygenDevice)
                .policies(asList(oxygenPrivacyPolicy1, oxygenPrivacyPolicy2))
                .document(document)
                .build();

        privacyPolicyReportService.add(oxygenPrivacyPolicyReport);

        //紫外線傳感器
        Device sensorDevice = Device.builder()
                .udn("40ceb1e7-6834-4e6a-9305-57348a2b8d0c")
                .name("UVM-30A紫外線傳感器")
                .type(Device.Type.Sensor)
                .manufacturer(Manufacturer.builder()
                        .name("台灣物聯科技")
                        .serialNumber("1234532545")
                        .url("https://www.taiwaniot.com.tw/")
                        .build())
                .model(Model.builder()
                        .name("UVM-30A紫外線傳感器")
                        .description("專為需要高可靠性和精確性測量紫外線指數（UVI）的場合所設計，且適合測量太陽光紫外線強度總量，適用於小尺寸裝置、行動電話等便攜產品。")
                        .url("https://www.taiwaniot.com.tw/product/uvm-30a%E7%B4%AB%E5%A4%96%E7%B7%9A%E5%82%B3%E6%84%9F%E5%99%A8%E6%A8%A1%E7%B5%84/")
                        .build())
                .upc("B0744D6C8X")
                .location("25.013068, 121.541651")
                .status(Device.Status.Disconnected)
                .build();

        deviceService.add(sensorDevice);

        PrivacyPolicy sensorPrivacyPolicy1 = PrivacyPolicy.builder()
                .id("abe5ca7b-780e-4857-87e6-014870fe0a3e")
                .description("本APP會蒐集使用者周遭紫外線強度作為第三方資料之地區環境分析資料。")
                .collector(Collector.builder()
                        .name("AirRadio")
                        .email("airradio@gmail.com.tw")
                        .phone("0987654177")
                        .build())
                .access(Access.NON_IDENT)
                .dispute(Dispute.builder()
                        .relatedOrganization("地方法院")
                        .type(Dispute.Type.LAW).build())
                .remedies(asList(Remedy.builder()
                        .type(Remedy.Type.LAW).build()))
                .statements(asList(Statement.builder()
                        .consequence("a1252c49-4188-4e6d-a32e-66604c664fb9")
                        .purposes(asList(Purpose.builder()
                                .type(Purpose.Type.PSEUDO_ANALYSIS)
                                .description("本APP會蒐集使用者周遭紫外線強度作為第三方資料之地區環境分析資料。")
                                .build()))
                        .data(asList(Datum.builder()
                                .type(Datum.Type.OTHER_CATEGORY)
                                .description("紫外線強度資料")
                                .build()))
                        .recipients(asList(Recipient.builder()
                                .entity("AirRadio")
                                .type(Recipient.Type.OURS)
                                .build()))
                        .retention(Retention.STATED_PURPOSE)
                        .build()))
                .build();

        document = resourceToMultipartFile(sensorResource)
                .flatMap(documentService::add)
                .orElse(Document.builder().build());

        PrivacyPolicyReport sensorPrivacyPolicyReport = PrivacyPolicyReport.builder()
                .id("0cfb6be3-6f0f-4e63-85b8-e9c936707c0a")
                .version("1.0")
                .description("本APP會蒐集使用者周遭紫外線強度作為第三方資料之地區環境分析資料。")
                .device(sensorDevice)
                .policies(asList(sensorPrivacyPolicy1))
                .document(document)
                .build();

        privacyPolicyReportService.add(sensorPrivacyPolicyReport);

        //粉塵感測器
        Device dustDevice = Device.builder()
                .udn("40ceb1e7-6834-4e6a-9305-57348a2b8asc")
                .name("G7 PMS7003 粉塵濃度感測器")
                .type(Device.Type.Sensor)
                .manufacturer(Manufacturer.builder()
                        .name("台灣物聯科技")
                        .serialNumber("1234532545")
                        .url("https://www.taiwaniot.com.tw/")
                        .build())
                .model(Model.builder()
                        .name("G7 PMS7003 粉塵濃度感測器")
                        .description("最新推出G7,全稱 PMS7003,厚度僅12mm,專為便攜式檢測產品設計。" +
                                "可兼容G1和G5,更小更薄,進出氣口在同一側,全金屬外殼。" +
                                "PM1.0、PM2.5、PM10濃度以及顆粒物個數等12個參數輸出。")
                        .url("https://www.taiwaniot.com.tw/product/%E6%94%80%E8%97%A4-g7-pms7003-pm1-0-pm2-5-pm10-%E7%B2%89%E5%A1%B5%E6%BF%83%E5%BA%A6%E6%84%9F%E6%B8%AC%E5%99%A8/")
                        .build())
                .upc("B0744D6C8X")
                .location("25.013068, 121.541651")
                .status(Device.Status.Disconnected)
                .build();

        deviceService.add(dustDevice);

        PrivacyPolicy dustPrivacyPolicy1 = PrivacyPolicy.builder()
                .id("abe5ca7b-780e-4857-87e6-014870fe0a1j")
                .description("本APP會蒐集使用者周遭空氣品質作為第三方資料之地區環境分析資料。")
                .collector(Collector.builder()
                        .name("AirRadio")
                        .email("airradio@gmail.com.tw")
                        .phone("0987654177")
                        .build())
                .access(Access.NON_IDENT)
                .dispute(Dispute.builder()
                        .relatedOrganization("地方法院")
                        .type(Dispute.Type.LAW).build())
                .remedies(asList(Remedy.builder()
                        .type(Remedy.Type.LAW).build()))
                .statements(asList(Statement.builder()
                        .consequence("a1252c49-4188-4e6d-a32e-66604c66s1r9")
                        .purposes(asList(Purpose.builder()
                                .type(Purpose.Type.PSEUDO_ANALYSIS)
                                .description("本APP會蒐集使用者周遭空氣品質作為第三方資料之地區環境分析資料。")
                                .build()))
                        .data(asList(Datum.builder()
                                .type(Datum.Type.OTHER_CATEGORY)
                                .description("空氣品質資料")
                                .build()))
                        .recipients(asList(Recipient.builder()
                                .entity("AirRadio")
                                .type(Recipient.Type.OURS)
                                .build()))
                        .retention(Retention.STATED_PURPOSE)
                        .build()))
                .build();

        document = resourceToMultipartFile(dustResource)
                .flatMap(documentService::add)
                .orElse(Document.builder().build());

        PrivacyPolicyReport dustPrivacyPolicyReport = PrivacyPolicyReport.builder()
                .id("0cfb6be3-6f0f-4e63-85b8-e9c936707c0a")
                .version("1.0")
                .description("本APP會蒐集使用者周遭空氣品質作為第三方資料之地區環境分析資料。")
                .device(dustDevice)
                .policies(asList(dustPrivacyPolicy1))
                .document(document)
                .build();

        privacyPolicyReportService.add(dustPrivacyPolicyReport);

        //溫度模組
        Device tempDevice = Device.builder()
                .udn("40ceb1e7-6834-4e6a-9305-57348as38asc")
                .name("DHT22 溫濕度模組")
                .type(Device.Type.Sensor)
                .manufacturer(Manufacturer.builder()
                        .name("台灣物聯科技")
                        .serialNumber("1234532545")
                        .url("https://www.taiwaniot.com.tw/")
                        .build())
                .model(Model.builder()
                        .name("DHT22 溫濕度模組")
                        .description("DHT22溫濕度感測器是一款含有已校準數位信號輸出的溫濕度複合感測器，" +
                                "它應用專用的數位模組採集技術和溫濕度傳感技術，來確保產品具有極高的可靠性與卓越的長期穩定性")
                        .url("https://www.taiwaniot.com.tw/product/dht22-%E6%BA%AB%E5%BA%A6%E6%A8%A1%E7%B5%84-%E6%BF%95%E5%BA%A6%E6%A8%A1%E7%B5%84-%E6%BA%AB%E6%BF%95%E5%BA%A6%E6%A8%A1%E7%B5%84-dht22/")
                        .build())
                .upc("B0744D6C8X")
                .location("25.013068, 121.541651")
                .status(Device.Status.Disconnected)
                .build();

        deviceService.add(tempDevice);

        PrivacyPolicy tempPrivacyPolicy1 = PrivacyPolicy.builder()
                .id("abe5ca7b-780e-4857-87e6-014870fe00e1")
                .description("本APP會蒐集使用者周遭溫度、濕度作為第三方資料之地區環境分析資料。")
                .collector(Collector.builder()
                        .name("AirRadio")
                        .email("airradio@gmail.com.tw")
                        .phone("0987654177")
                        .build())
                .access(Access.NON_IDENT)
                .dispute(Dispute.builder()
                        .relatedOrganization("地方法院")
                        .type(Dispute.Type.LAW).build())
                .remedies(asList(Remedy.builder()
                        .type(Remedy.Type.LAW).build()))
                .statements(asList(Statement.builder()
                        .consequence("a1252c49-4188-4e6d-a32e-66604c6621f9")
                        .purposes(asList(Purpose.builder()
                                .type(Purpose.Type.PSEUDO_ANALYSIS)
                                .description("本APP會蒐集使用者周遭溫度作為第三方資料之地區環境分析資料。")
                                .build()))
                        .data(asList(Datum.builder()
                                .type(Datum.Type.OTHER_CATEGORY)
                                .description("溫度資料")
                                .build()))
                        .recipients(asList(Recipient.builder()
                                .entity("AirRadio")
                                .type(Recipient.Type.OURS)
                                .build()))
                        .retention(Retention.STATED_PURPOSE)
                        .build(), Statement.builder()
                        .consequence("a1252c49-4188-4e6d-a32e-6204c63s1r9")
                        .purposes(asList(Purpose.builder()
                                .type(Purpose.Type.PSEUDO_ANALYSIS)
                                .description("本APP會蒐集使用者周遭濕度作為第三方資料之地區環境分析資料。")
                                .build()))
                        .data(asList(Datum.builder()
                                .type(Datum.Type.OTHER_CATEGORY)
                                .description("濕度資料")
                                .build()))
                        .recipients(asList(Recipient.builder()
                                .entity("AirRadio")
                                .type(Recipient.Type.OURS)
                                .build()))
                        .retention(Retention.STATED_PURPOSE)
                        .build()
                )).build();

        document = resourceToMultipartFile(tempResource)
                .flatMap(documentService::add)
                .orElse(Document.builder().build());

        PrivacyPolicyReport tempPrivacyPolicyReport = PrivacyPolicyReport.builder()
                .id("0cfb6be3-6f0f-4e63-85b8-e9c936707c0a")
                .version("1.0")
                .description("本APP會蒐集使用者周遭周遭溫度、濕度作為第三方資料之地區環境分析資料。")
                .device(tempDevice)
                .policies(asList(tempPrivacyPolicy1))
                .document(document)
                .build();

        privacyPolicyReportService.add(tempPrivacyPolicyReport);

        //氣體感測器
        Device gasDevice = Device.builder()
                .udn("40ceb1e7-6834-4e6a-9305-57348ast5asc")
                .name("MQ-4 氣體感測器")
                .type(Device.Type.Sensor)
                .manufacturer(Manufacturer.builder()
                        .name("台灣物聯科技")
                        .serialNumber("1234532545")
                        .url("https://www.taiwaniot.com.tw/")
                        .build())
                .model(Model.builder()
                        .name("DHT22 溫濕度模組")
                        .description("MQ-4氣體感測器所使用的氣敏材料是在清潔空氣中電導率較低的二氧化錫 (SnO2)。" +
                                "MQ-4氣體感測器對甲烷的靈敏度高，對丙烷、丁烷也有較好的靈敏度。" +
                                "這種感測器可檢測多種可燃性氣體，特別是天然氣，是一款適合多種應用的低成本感測器。")
                        .url("https://www.taiwaniot.com.tw/product/mq-4-ch4-%E5%A4%A9%E7%84%B6%E6%B0%A3%E3%80%81%E7%94%B2%E7%83%B7%E6%84%9F%E6%B8%AC%E5%99%A8%E6%A8%A1%E7%B5%84/")
                        .build())
                .upc("B0744D6C8X")
                .location("25.013068, 121.541651")
                .status(Device.Status.Disconnected)
                .build();

        deviceService.add(gasDevice);

        PrivacyPolicy gasPrivacyPolicy1 = PrivacyPolicy.builder()
                .id("abe5ca7b-780e-4857-87e6-014642fe00e1")
                .description("本APP會蒐集使用者周遭氣體作為第三方資料之地區環境分析資料。")
                .collector(Collector.builder()
                        .name("AirRadio")
                        .email("airradio@gmail.com.tw")
                        .phone("0987654177")
                        .build())
                .access(Access.NON_IDENT)
                .dispute(Dispute.builder()
                        .relatedOrganization("地方法院")
                        .type(Dispute.Type.LAW).build())
                .remedies(asList(Remedy.builder()
                        .type(Remedy.Type.LAW).build()))
                .statements(asList(Statement.builder()
                        .consequence("a1252c49-4188-4e6d-a32e-66604c6621f9")
                        .purposes(asList(Purpose.builder()
                                .type(Purpose.Type.PSEUDO_ANALYSIS)
                                .description("本APP會蒐集使用者周遭氣體作為第三方資料之地區環境分析資料。")
                                .build()))
                        .data(asList(Datum.builder()
                                .type(Datum.Type.OTHER_CATEGORY)
                                .description("氣體資料")
                                .build()))
                        .recipients(asList(Recipient.builder()
                                .entity("AirRadio")
                                .type(Recipient.Type.OURS)
                                .build()))
                        .retention(Retention.STATED_PURPOSE)
                        .build()))
                .build();

        document = resourceToMultipartFile(gasResource)
                .flatMap(documentService::add)
                .orElse(Document.builder().build());

        PrivacyPolicyReport gasPrivacyPolicyReport = PrivacyPolicyReport.builder()
                .id("0cfb6be3-6f0f-4e63-85b8-e9c936707c0a")
                .version("1.0")
                .description("本APP會蒐集使用者周遭周遭氣體作為第三方資料之地區環境分析資料。")
                .device(gasDevice)
                .policies(asList(gasPrivacyPolicy1))
                .document(document)
                .build();

        privacyPolicyReportService.add(gasPrivacyPolicyReport);

        //==================================================================================
        //心跳感測裝置
        Device heartbeatDevice = Device.builder()
                .udn("2udwl107-4128-4e6d-a32e-3xg04i62rukl")
                .name("心跳感測裝置")
                .type(Device.Type.Sensor)
                .manufacturer(Manufacturer.builder()
                        .name("Maxim Integrated")
                        .serialNumber("3176927193")
                        .url("https://www.maximintegrated.com/en.html")
                        .build())
                .model(Model.builder()
                        .name("心跳感測裝置")
                        .description("本設備檢測人體內產生的小信號，例如心臟產生的電信號，此信號通常經過調理後傳輸至微控制器，進行儲存、計算或顯示在健康監測設備上。本設備測量數據用於健身監測，或者被醫療保健專家用於判定被觀察病人的總體健康狀況")
                        .url("https://www.maximintegrated.com/en/products/sensors/MAX30100.html")
                        .build())
                .upc("B00HXXO332")
                .location("25.013068, 121.541651")
                .status(Device.Status.Disconnected)
                .build();

        deviceService.add(heartbeatDevice);

        PrivacyPolicy heartbeatPrivacyPolicy = PrivacyPolicy.builder()
                .id("abe5ca7b-780e-4857-87e6-015370fe0a3e")
                .description("本APP會蒐集使用者心跳作為第三方之分析資料。")
                .collector(Collector.builder()
                        .name("AirRadio")
                        .email("airradio@gmail.com.tw")
                        .phone("0987654177")
                        .build())
                .access(Access.NON_IDENT)
                .dispute(Dispute.builder()
                        .relatedOrganization("地方法院")
                        .type(Dispute.Type.LAW).build())
                .remedies(asList(Remedy.builder()
                        .type(Remedy.Type.LAW)
                        .build()))
                .statements(asList(Statement.builder()
                        .consequence("a1252c49-4188-4e6d-a32e-66604c664fl4")
                        .purposes(asList(Purpose.builder()
                                .type(Purpose.Type.PSEUDO_ANALYSIS)
                                .description("本APP會蒐集使用者心跳作為第三方之分析資料。")
                                .build()))
                        .data(asList(Datum.builder()
                                .type(Datum.Type.OTHER_CATEGORY)
                                .description("心跳健康資料")
                                .build()))
                        .recipients(asList(Recipient.builder()
                                .entity("AirRadio")
                                .type(Recipient.Type.OURS)
                                .build()))
                        .retention(Retention.STATED_PURPOSE)
                        .build(), Statement.builder()
                        .consequence("a1252c49-4188-4e6d-a32e-66604c664f45")
                        .purposes(asList(Purpose.builder()
                                .type(Purpose.Type.PSEUDO_ANALYSIS)
                                .description("本APP會蒐集使用者心跳作為第三方之分析資料。")
                                .build()))
                        .data(asList(Datum.builder()
                                .type(Datum.Type.OTHER_CATEGORY)
                                .description("心跳健康資料")
                                .build()))
                        .recipients(asList(Recipient.builder()
                                .entity("AirRadio")
                                .type(Recipient.Type.OURS)
                                .build()))
                        .retention(Retention.STATED_PURPOSE)
                        .build()
                ))
                .build();

        document = resourceToMultipartFile(oxygenResource)
                .flatMap(documentService::add)
                .orElse(Document.builder().build());

        PrivacyPolicyReport heartBeatPolicyReport = PrivacyPolicyReport.builder()
                .id("0cfb6be3-6f0f-4e63-85b8-e9c936707c0a")
                .version("1.0")
                .description("本APP會蒐集使用者心跳作為第三方之分析資料。")
                .device(heartbeatDevice)
                .policies(asList(heartbeatPrivacyPolicy))
                .document(document)
                .build();

        privacyPolicyReportService.add(heartBeatPolicyReport);

        //血氧感測裝置
        Device oxygen2Device = Device.builder()
                .udn("z5fx8c6b-4128-4e6d-a32e-tyribifgsne9")
                .name("血氧感測裝置")
                .type(Device.Type.Sensor)
                .manufacturer(Manufacturer.builder()
                        .name("Maxim Integrated")
                        .serialNumber("3176927193")
                        .url("https://www.maximintegrated.com/en.html")
                        .build())
                .model(Model.builder()
                        .name("血氧感測裝置")
                        .description("本設備檢測人體內血液中氧濃度含量，" +
                                "例如能監測動脈中攜帶氧的血紅蛋白與不攜帶氧的血紅蛋白的比例，" +
                                "本設備測量數據用於健身監測，或者被醫療保健專家用於判定被觀察病人的總體健康狀況")
                        .url("https://www.maximintegrated.com/en/products/sensors/MAX30100.html")
                        .build())
                .upc("B00HXXO332")
                .location("25.013068, 121.541651")
                .status(Device.Status.Disconnected)
                .build();

        deviceService.add(oxygen2Device);

        PrivacyPolicy oxygen2PrivacyPolicy = PrivacyPolicy.builder()
                .id("abe5ca7b-780e-4857-87e6-014870fe0a3e")
                .description("本APP會蒐集使用者血氧作為第三方之分析資料。")
                .collector(Collector.builder()
                        .name("AirRadio")
                        .email("airradio@gmail.com.tw")
                        .phone("0987654177")
                        .build())
                .access(Access.NON_IDENT)
                .dispute(Dispute.builder()
                        .relatedOrganization("地方法院")
                        .type(Dispute.Type.LAW).build())
                .remedies(asList(Remedy.builder()
                        .type(Remedy.Type.LAW)
                        .build()))
                .statements(asList(Statement.builder()
                        .consequence("a1252c49-4188-4e6d-a32e-66604c664f48")
                        .purposes(asList(Purpose.builder()
                                .type(Purpose.Type.PSEUDO_ANALYSIS)
                                .description("本APP會蒐集使用者血氧作為第三方之分析資料。")
                                .build()))
                        .data(asList(Datum.builder()
                                .type(Datum.Type.OTHER_CATEGORY)
                                .description("血氧資料")
                                .build()))
                        .recipients(asList(Recipient.builder()
                                .entity("AirRadio")
                                .type(Recipient.Type.OURS)
                                .build()))
                        .retention(Retention.STATED_PURPOSE)
                        .build(), Statement.builder()
                        .consequence("a1252c49-4188-4e6d-a32e-66604c664f89")
                        .purposes(asList(Purpose.builder()
                                .type(Purpose.Type.PSEUDO_ANALYSIS)
                                .description("本APP會蒐集使用者血氧作為第三方之分析資料。")
                                .build()))
                        .data(asList(Datum.builder()
                                .type(Datum.Type.OTHER_CATEGORY)
                                .description("血氧資料")
                                .build()))
                        .recipients(asList(Recipient.builder()
                                .entity("AirRadio")
                                .type(Recipient.Type.OURS)
                                .build()))
                        .retention(Retention.STATED_PURPOSE)
                        .build()
                )).build();

        document = resourceToMultipartFile(oxygenResource)
                .flatMap(documentService::add)
                .orElse(Document.builder().build());

        PrivacyPolicyReport oxygen2PrivacyPolicyReport = PrivacyPolicyReport.builder()
                .id("0cfb6be3-6f0f-4e63-85b8-e9c936707c0a")
                .version("1.0")
                .description("本設備檢測人體內血液中氧濃度含量，" +
                        "例如能監測動脈中攜帶氧的血紅蛋白與不攜帶氧的血紅蛋白的比例，" +
                        "本設備測量數據用於健身監測，或者被醫療保健專家用於判定被觀察病人的總體健康狀況")
                .device(oxygen2Device)
                .policies(asList(oxygen2PrivacyPolicy))
                .document(document)
                .build();

        privacyPolicyReportService.add(oxygen2PrivacyPolicyReport);

        //PM2.5粉塵感測裝置
        Device dustDevice2 = Device.builder()
                .udn("cx9lrnuy-6834-4e6a-9305-s3zlkheeplcc")
                .name("PM2.5粉塵感測裝置")
                .type(Device.Type.Sensor)
                .manufacturer(Manufacturer.builder()
                        .name("台灣物聯科技")
                        .serialNumber("6307683948")
                        .url("https://www.taiwaniot.com.tw/")
                        .build())
                .model(Model.builder()
                        .name("PM2.5粉塵感測裝置")
                        .description("最新推出G7,全稱 PMS7003,厚度僅12mm,專為便攜式檢測產品設計。" +
                                "可兼容G1和G5,更小更薄,進出氣口在同一側,全金屬外殼。" +
                                "PM1.0、PM2.5、PM10濃度以及顆粒物個數等12個參數輸出。")
                        .url("https://www.taiwaniot.com.tw/product/%E6%94%80%E8%97%A4-g7-pms7003-pm1-0-pm2-5-pm10-%E7%B2%89%E5%A1%B5%E6%BF%83%E5%BA%A6%E6%84%9F%E6%B8%AC%E5%99%A8/")
                        .build())
                .upc("B0744D6C8X")
                .location("25.013068, 121.541651")
                .status(Device.Status.Disconnected)
                .build();

        deviceService.add(dustDevice2);

        PrivacyPolicy dustPrivacyPolicy2 = PrivacyPolicy.builder()
                .id("abe5ca7b-780e-4857-87e6-014870fe0a1j")
                .description("本APP會蒐集使用者周遭空氣品質作為第三方資料之地區環境分析資料。")
                .collector(Collector.builder()
                        .name("AirRadio")
                        .email("airradio@gmail.com.tw")
                        .phone("0987654177")
                        .build())
                .access(Access.NON_IDENT)
                .dispute(Dispute.builder()
                        .relatedOrganization("地方法院")
                        .type(Dispute.Type.LAW).build())
                .remedies(asList(Remedy.builder()
                        .type(Remedy.Type.LAW).build()))
                .statements(asList(Statement.builder()
                        .consequence("a1252c49-4188-4e6d-a32e-66604c66s1r9")
                        .purposes(asList(Purpose.builder()
                                .type(Purpose.Type.PSEUDO_ANALYSIS)
                                .description("本APP會蒐集使用者周遭空氣品質作為第三方資料之地區環境分析資料。")
                                .build()))
                        .data(asList(Datum.builder()
                                .type(Datum.Type.OTHER_CATEGORY)
                                .description("空氣品質資料")
                                .build()))
                        .recipients(asList(Recipient.builder()
                                .entity("AirRadio")
                                .type(Recipient.Type.OURS)
                                .build()))
                        .retention(Retention.STATED_PURPOSE)
                        .build()))
                .build();

        document = resourceToMultipartFile(dustResource)
                .flatMap(documentService::add)
                .orElse(Document.builder().build());

        PrivacyPolicyReport dustPrivacyPolicyReport2 = PrivacyPolicyReport.builder()
                .id("0cfb6be3-6f0f-4e63-85b8-e9c936707c0a")
                .version("1.0")
                .description("本APP會蒐集使用者周遭空氣品質作為第三方資料之地區環境分析資料。")
                .device(dustDevice2)
                .policies(asList(dustPrivacyPolicy2))
                .document(document)
                .build();

        privacyPolicyReportService.add(dustPrivacyPolicyReport2);

        //紫外線感測裝置
        Device sensorDevice2 = Device.builder()
                .udn("72ht8ggp-6834-4e6a-9305-7hq4a9pccsfd")
                .name("紫外線感測裝置")
                .type(Device.Type.Sensor)
                .manufacturer(Manufacturer.builder()
                        .name("台灣物聯科技")
                        .serialNumber("6307683948")
                        .url("https://www.taiwaniot.com.tw/")
                        .build())
                .model(Model.builder()
                        .name("UVM-30A紫外線傳感器")
                        .description("專為需要高可靠性和精確性測量紫外線指數（UVI）的場合所設計，且適合測量太陽光紫外線強度總量，適用於小尺寸裝置、行動電話等便攜產品。")
                        .url("https://www.taiwaniot.com.tw/product/uvm-30a%E7%B4%AB%E5%A4%96%E7%B7%9A%E5%82%B3%E6%84%9F%E5%99%A8%E6%A8%A1%E7%B5%84/")
                        .build())
                .upc("B0744D6C8X")
                .location("25.013068, 121.541651")
                .status(Device.Status.Disconnected)
                .build();

        deviceService.add(sensorDevice2);

        PrivacyPolicy sensorPrivacyPolicy2 = PrivacyPolicy.builder()
                .id("abe5ca7b-780e-4857-87e6-014870fe0a3e")
                .description("本APP會蒐集使用者周遭紫外線強度作為第三方資料之地區環境分析資料。")
                .collector(Collector.builder()
                        .name("AirRadio")
                        .email("airradio@gmail.com.tw")
                        .phone("0987654177")
                        .build())
                .access(Access.NON_IDENT)
                .dispute(Dispute.builder()
                        .relatedOrganization("地方法院")
                        .type(Dispute.Type.LAW).build())
                .remedies(asList(Remedy.builder()
                        .type(Remedy.Type.LAW).build()))
                .statements(asList(Statement.builder()
                        .consequence("a1252c49-4188-4e6d-a32e-66604c664fb9")
                        .purposes(asList(Purpose.builder()
                                .type(Purpose.Type.PSEUDO_ANALYSIS)
                                .description("本APP會蒐集使用者周遭紫外線強度作為第三方資料之地區環境分析資料。")
                                .build()))
                        .data(asList(Datum.builder()
                                .type(Datum.Type.OTHER_CATEGORY)
                                .description("紫外線強度資料")
                                .build()))
                        .recipients(asList(Recipient.builder()
                                .entity("AirRadio")
                                .type(Recipient.Type.OURS)
                                .build()))
                        .retention(Retention.STATED_PURPOSE)
                        .build()))
                .build();

        document = resourceToMultipartFile(sensorResource)
                .flatMap(documentService::add)
                .orElse(Document.builder().build());

        PrivacyPolicyReport sensorPrivacyPolicyReport2 = PrivacyPolicyReport.builder()
                .id("0cfb6be3-6f0f-4e63-85b8-e9c936707c0a")
                .version("1.0")
                .description("本APP會蒐集使用者周遭紫外線強度作為第三方資料之地區環境分析資料。")
                .device(sensorDevice2)
                .policies(asList(sensorPrivacyPolicy2))
                .document(document)
                .build();

        privacyPolicyReportService.add(sensorPrivacyPolicyReport2);

        //濕度感測裝置
        Device humidityDevice = Device.builder()
                .udn("40ceb1e7-6834-4e6a-9305-57348as38asc")
                .name("濕度感測裝置")
                .type(Device.Type.Sensor)
                .manufacturer(Manufacturer.builder()
                        .name("台灣物聯科技")
                        .serialNumber("6307683948")
                        .url("https://www.taiwaniot.com.tw/")
                        .build())
                .model(Model.builder()
                        .name("濕度感測裝置")
                        .description("濕度感測器是一款含有已校準數位信號輸出的濕度感測器，" +
                                "它應用專用的數位模組採集技術和濕度傳感技術，來確保產品具有極高的可靠性與卓越的長期穩定性")
                        .url("https://www.taiwaniot.com.tw/product/dht22-%E6%BA%AB%E5%BA%A6%E6%A8%A1%E7%B5%84-%E6%BF%95%E5%BA%A6%E6%A8%A1%E7%B5%84-%E6%BA%AB%E6%BF%95%E5%BA%A6%E6%A8%A1%E7%B5%84-dht22/")
                        .build())
                .upc("B0744D6C8X")
                .location("25.013068, 121.541651")
                .status(Device.Status.Disconnected)
                .build();

        deviceService.add(humidityDevice);

        PrivacyPolicy humidityPrivacyPolicy = PrivacyPolicy.builder()
                .id("abe5ca7b-780e-4857-87e6-014870fe00e1")
                .description("本APP會蒐集使用者周遭濕度作為第三方資料之地區環境分析資料。")
                .collector(Collector.builder()
                        .name("AirRadio")
                        .email("airradio@gmail.com.tw")
                        .phone("0987654177")
                        .build())
                .access(Access.NON_IDENT)
                .dispute(Dispute.builder()
                        .relatedOrganization("地方法院")
                        .type(Dispute.Type.LAW).build())
                .remedies(asList(Remedy.builder()
                        .type(Remedy.Type.LAW).build()))
                .statements(asList(Statement.builder()
                        .consequence("a1252c49-4188-4e6d-a32e-66604c6621f9")
                        .purposes(asList(Purpose.builder()
                                .type(Purpose.Type.PSEUDO_ANALYSIS)
                                .description("本APP會蒐集使用者周遭濕度作為第三方資料之地區環境分析資料。")
                                .build()))
                        .data(asList(Datum.builder()
                                .type(Datum.Type.OTHER_CATEGORY)
                                .description("濕度資料")
                                .build()))
                        .recipients(asList(Recipient.builder()
                                .entity("AirRadio")
                                .type(Recipient.Type.OURS)
                                .build()))
                        .retention(Retention.STATED_PURPOSE)
                        .build()
                )).build();

        document = resourceToMultipartFile(tempResource)
                .flatMap(documentService::add)
                .orElse(Document.builder().build());

        PrivacyPolicyReport humidityPrivacyPolicyReport = PrivacyPolicyReport.builder()
                .id("0cfb6be3-6f0f-4e63-85b8-e9c936707c0a")
                .version("1.0")
                .description("本APP會蒐集使用者周遭周遭濕度作為第三方資料之地區環境分析資料。")
                .device(humidityDevice)
                .policies(asList(humidityPrivacyPolicy))
                .document(document)
                .build();

        privacyPolicyReportService.add(humidityPrivacyPolicyReport);

        //溫度感測裝置
        Device temp2Device = Device.builder()
                .udn("knqxzdmu-6834-4e6a-9305-spyp3gvix2d4")
                .name("溫度感測裝置")
                .type(Device.Type.Sensor)
                .manufacturer(Manufacturer.builder()
                        .name("台灣物聯科技")
                        .serialNumber("6307683948")
                        .url("https://www.taiwaniot.com.tw/")
                        .build())
                .model(Model.builder()
                        .name("溫度感測裝置")
                        .description("DHT22溫濕度感測器是一款含有已校準數位信號輸出的溫濕度複合感測器，" +
                                "它應用專用的數位模組採集技術和溫濕度傳感技術，來確保產品具有極高的可靠性與卓越的長期穩定性")
                        .url("https://www.taiwaniot.com.tw/product/dht22-%E6%BA%AB%E5%BA%A6%E6%A8%A1%E7%B5%84-%E6%BF%95%E5%BA%A6%E6%A8%A1%E7%B5%84-%E6%BA%AB%E6%BF%95%E5%BA%A6%E6%A8%A1%E7%B5%84-dht22/")
                        .build())
                .upc("B0744D6C8X")
                .location("25.013068, 121.541651")
                .status(Device.Status.Disconnected)
                .build();

        deviceService.add(temp2Device);

        PrivacyPolicy tempPrivacyPolicy2 = PrivacyPolicy.builder()
                .id("abe5ca7b-780e-4857-87e6-014870fe00e1")
                .description("本APP會蒐集使用者周遭溫度作為第三方資料之地區環境分析資料。")
                .collector(Collector.builder()
                        .name("AirRadio")
                        .email("airradio@gmail.com.tw")
                        .phone("0987654177")
                        .build())
                .access(Access.NON_IDENT)
                .dispute(Dispute.builder()
                        .relatedOrganization("地方法院")
                        .type(Dispute.Type.LAW).build())
                .remedies(asList(Remedy.builder()
                        .type(Remedy.Type.LAW).build()))
                .statements(asList(Statement.builder()
                        .consequence("a1252c49-4188-4e6d-a32e-66604c6621f9")
                        .purposes(asList(Purpose.builder()
                                .type(Purpose.Type.PSEUDO_ANALYSIS)
                                .description("本APP會蒐集使用者周遭溫度作為第三方資料之地區環境分析資料。")
                                .build()))
                        .data(asList(Datum.builder()
                                .type(Datum.Type.OTHER_CATEGORY)
                                .description("溫度資料")
                                .build()))
                        .recipients(asList(Recipient.builder()
                                .entity("AirRadio")
                                .type(Recipient.Type.OURS)
                                .build()))
                        .retention(Retention.STATED_PURPOSE)
                        .build()
                )).build();

        document = resourceToMultipartFile(tempResource)
                .flatMap(documentService::add)
                .orElse(Document.builder().build());

        PrivacyPolicyReport tempPrivacyPolicyReport2 = PrivacyPolicyReport.builder()
                .id("0cfb6be3-6f0f-4e63-85b8-e9c936707c0a")
                .version("1.0")
                .description("本APP會蒐集使用者周遭周遭溫度作為第三方資料之地區環境分析資料。")
                .device(temp2Device)
                .policies(asList(tempPrivacyPolicy2))
                .document(document)
                .build();

        privacyPolicyReportService.add(tempPrivacyPolicyReport2);

        //溫室氣體(甲烷)裝置
        Device gas2Device = Device.builder()
                .udn("iatm4k4x-6834-4e6a-9305-x4sqjb9wkir5")
                .name("溫室氣體(甲烷)裝置")
                .type(Device.Type.Sensor)
                .manufacturer(Manufacturer.builder()
                        .name("台灣物聯科技")
                        .serialNumber("6307683948")
                        .url("https://www.taiwaniot.com.tw/")
                        .build())
                .model(Model.builder()
                        .name("溫室氣體(甲烷)裝置")
                        .description("MQ-4氣體感測器所使用的氣敏材料是在清潔空氣中電導率較低的二氧化錫 (SnO2)。" +
                                "MQ-4氣體感測器對甲烷的靈敏度高，是一款適合多種應用的低成本感測器。")
                        .url("https://www.taiwaniot.com.tw/product/mq-4-ch4-%E5%A4%A9%E7%84%B6%E6%B0%A3%E3%80%81%E7%94%B2%E7%83%B7%E6%84%9F%E6%B8%AC%E5%99%A8%E6%A8%A1%E7%B5%84/")
                        .build())
                .upc("B0744D6C8X")
                .location("25.013068, 121.541651")
                .status(Device.Status.Disconnected)
                .build();

        deviceService.add(gas2Device);

        PrivacyPolicy gasPrivacyPolicy2 = PrivacyPolicy.builder()
                .id("abe5ca7b-780e-4857-87e6-014642fe00e1")
                .description("本APP會蒐集使用者周遭氣體作為第三方資料之地區環境分析資料。")
                .collector(Collector.builder()
                        .name("AirRadio")
                        .email("airradio@gmail.com.tw")
                        .phone("0987654177")
                        .build())
                .access(Access.NON_IDENT)
                .dispute(Dispute.builder()
                        .relatedOrganization("地方法院")
                        .type(Dispute.Type.LAW).build())
                .remedies(asList(Remedy.builder()
                        .type(Remedy.Type.LAW).build()))
                .statements(asList(Statement.builder()
                        .consequence("a1252c49-4188-4e6d-a32e-66604c6621f9")
                        .purposes(asList(Purpose.builder()
                                .type(Purpose.Type.PSEUDO_ANALYSIS)
                                .description("本APP會蒐集使用者周遭氣體作為第三方資料之地區環境分析資料。")
                                .build()))
                        .data(asList(Datum.builder()
                                .type(Datum.Type.OTHER_CATEGORY)
                                .description("氣體資料")
                                .build()))
                        .recipients(asList(Recipient.builder()
                                .entity("AirRadio")
                                .type(Recipient.Type.OURS)
                                .build()))
                        .retention(Retention.STATED_PURPOSE)
                        .build()))
                .build();

        document = resourceToMultipartFile(gasResource)
                .flatMap(documentService::add)
                .orElse(Document.builder().build());

        PrivacyPolicyReport gasPrivacyPolicyReport2 = PrivacyPolicyReport.builder()
                .id("0cfb6be3-6f0f-4e63-85b8-e9c936707c0a")
                .version("1.0")
                .description("本APP會蒐集使用者周遭周遭氣體作為第三方資料之地區環境分析資料。")
                .device(gas2Device)
                .policies(asList(gasPrivacyPolicy2))
                .document(document)
                .build();

        privacyPolicyReportService.add(gasPrivacyPolicyReport2);

        //天然氣感測裝置
        Device gas3Device = Device.builder()
                .udn("3fvrenhl-6834-4e6a-9305-p7cujv6kfp7v")
                .name("天然氣感測裝置")
                .type(Device.Type.Sensor)
                .manufacturer(Manufacturer.builder()
                        .name("台灣物聯科技")
                        .serialNumber("6307683948")
                        .url("https://www.taiwaniot.com.tw/")
                        .build())
                .model(Model.builder()
                        .name("天然氣感測裝置")
                        .description("MQ-4氣體感測器所使用的氣敏材料是在清潔空氣中電導率較低的二氧化錫 (SnO2)。" +
                                "此感測器可檢測多種可燃性氣體，特別是天然氣，是一款適合多種應用的低成本感測器。")
                        .url("https://www.taiwaniot.com.tw/product/mq-4-ch4-%E5%A4%A9%E7%84%B6%E6%B0%A3%E3%80%81%E7%94%B2%E7%83%B7%E6%84%9F%E6%B8%AC%E5%99%A8%E6%A8%A1%E7%B5%84/")
                        .build())
                .upc("B0744D6C8X")
                .location("25.013068, 121.541651")
                .status(Device.Status.Disconnected)
                .build();

        deviceService.add(gas3Device);

        PrivacyPolicy gasPrivacyPolicy3 = PrivacyPolicy.builder()
                .id("abe5ca7b-780e-4857-87e6-014642fe00e1")
                .description("本APP會蒐集使用者周遭天然氣作為第三方資料之地區環境分析資料。")
                .collector(Collector.builder()
                        .name("AirRadio")
                        .email("airradio@gmail.com.tw")
                        .phone("0987654177")
                        .build())
                .access(Access.NON_IDENT)
                .dispute(Dispute.builder()
                        .relatedOrganization("地方法院")
                        .type(Dispute.Type.LAW).build())
                .remedies(asList(Remedy.builder()
                        .type(Remedy.Type.LAW).build()))
                .statements(asList(Statement.builder()
                        .consequence("a1252c49-4188-4e6d-a32e-66604c6621f9")
                        .purposes(asList(Purpose.builder()
                                .type(Purpose.Type.PSEUDO_ANALYSIS)
                                .description("本APP會蒐集使用者周遭天然氣作為第三方資料之地區環境分析資料。")
                                .build()))
                        .data(asList(Datum.builder()
                                .type(Datum.Type.OTHER_CATEGORY)
                                .description("天然氣資料")
                                .build()))
                        .recipients(asList(Recipient.builder()
                                .entity("AirRadio")
                                .type(Recipient.Type.OURS)
                                .build()))
                        .retention(Retention.STATED_PURPOSE)
                        .build()))
                .build();

        document = resourceToMultipartFile(gasResource)
                .flatMap(documentService::add)
                .orElse(Document.builder().build());

        PrivacyPolicyReport gasPrivacyPolicyReport3 = PrivacyPolicyReport.builder()
                .id("0cfb6be3-6f0f-4e63-85b8-e9c936707c0a")
                .version("1.0")
                .description("本APP會蒐集使用者周遭周遭天然氣作為第三方資料之地區環境分析資料。")
                .device(gas3Device)
                .policies(asList(gasPrivacyPolicy3))
                .document(document)
                .build();

        privacyPolicyReportService.add(gasPrivacyPolicyReport3);
    }

    private Optional<MockMultipartFile> resourceToMultipartFile(Resource resource) {
        try {
            InputStream file = resource.getInputStream();
            return Optional.ofNullable(new MockMultipartFile(resource.getFilename(), resource.getFilename(),
                    "application/pdf", resource.getInputStream()));
        } catch (IOException e) {
            e.printStackTrace();
        }
        return Optional.empty();
    }
}